@@ -1,9 +1,11 @@
 /*
  * Copyright 2013 Canonical Ltd.
+ * Copyright 2021-2023 Robert Tari
  *
  * Authors:
  *   Charles Kerr <charles.kerr@canonical.com>
  *   Ted Gould <ted@canonical.com>
+ *   Robert Tari <robert@tari.in>
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3, as published
@@ -91,8 +93,6 @@ ido_alarm_menu_item_new_from_model (GMenuItem    * menu_item,
   for (i=0; i<n; i++)
     g_value_unset (&values[i]);
 
-  g_free(names);
-
   /* add an ActionHelper */
 
   if (g_menu_item_get_attribute (menu_item, "action", "s", &str))
